aboutsummaryrefslogtreecommitdiff
path: root/src/txmempool.h
diff options
context:
space:
mode:
authorMatt Corallo <git@bluematt.me>2015-10-21 17:44:00 -0700
committerMatt Corallo <git@bluematt.me>2015-12-01 15:50:39 -0800
commitb2e74bd292460ca00fefc6356594318307365397 (patch)
treee7a0f8fbf7f9e9b33a72f6f2bd5e74cfe8831d41 /src/txmempool.h
parent74d0f902628472cd0cee66121ef0311eec201c40 (diff)
downloadbitcoin-b2e74bd292460ca00fefc6356594318307365397.tar.xz
Get the set of now-uncacheable-txn from CTxMemPool::TrimToSize
Diffstat (limited to 'src/txmempool.h')
-rw-r--r--src/txmempool.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/txmempool.h b/src/txmempool.h
index 5652969f4b..9203171868 100644
--- a/src/txmempool.h
+++ b/src/txmempool.h
@@ -483,8 +483,11 @@ public:
*/
CFeeRate GetMinFee(size_t sizelimit) const;
- /** Remove transactions from the mempool until its dynamic size is <= sizelimit. */
- void TrimToSize(size_t sizelimit);
+ /** Remove transactions from the mempool until its dynamic size is <= sizelimit.
+ * pvNoSpendsRemaining, if set, will be populated with the list of transactions
+ * which are not in mempool which no longer have any spends in this mempool.
+ */
+ void TrimToSize(size_t sizelimit, std::vector<uint256>* pvNoSpendsRemaining=NULL);
/** Expire all transaction (and their dependencies) in the mempool older than time. Return the number of removed transactions. */
int Expire(int64_t time);